@@ -66,8 +66,6 @@ try:
 except ImportError:
     ROPE_AVAILABLE = False
 
-from elpy.utils import autoimport
-
 
 def options(description, **kwargs):
     """Decorator to set some options on a method."""
@@ -226,10 +224,6 @@ class Refactor(object):
         changes = refactor.organize_imports(self.resource)
         return translate_changes(changes)
 
-    @options("Add missing imports", category="Imports")
-    def refactor_add_missing_imports(self):
-        return autoimport.get_changes(self.resource.real_path)
-
     @options("Convert the current module into a package", category="Module",
              available=ROPE_AVAILABLE)
     def refactor_module_to_package(self):
